Name: monotone
Version: 0.41
Release: 1%{?dist}

Summary: A free, distributed version control system
Group: Development/Tools
License: GPLv2+

URL: http://monotone.ca/
Source0: http://monotone.ca/downloads/%{version}/%{name}-%{version}.tar.gz
Source1: monotone.init
Source2: monotone.sysconfig
Source3: README.monotone-server

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: zlib-devel
BuildRequires: boost-devel >= 1.33.1
%if 1
%define bundled_sqlite yes
%else
# In fact, monotone has a locally-hacked 3.2.7, so we can't replace it.
BuildRequires: sqlite-devel >= 3.2.7
%define bundled_sqlite no
%endif
# monotone has local hacks in lua 5.0.2 as well, sigh.
%define bundled_lua 1
%if %{bundled_lua} == 0
BuildRequires: lua
%endif

# The test suite needs cvs.
BuildRequires: cvs

# We need Emacs to byte-compile the Emacs Lisp code.
BuildRequires: emacs

Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

%description
monotone is a free, distributed version control system.
It provides fully disconnected operation, manages complete
tree versions, keeps its state in a local transactional
database, supports overlapping branches and extensible
metadata, exchanges work over plain network protocols,
performs history-sensitive merging, and delegates trust
functions to client-side RSA certificates.

%package server
Summary: Standalone server setup for monotone
Requires: monotone = %{version}-%{release}
Requires(pre): shadow-utils
Requires(post): chkconfig
Requires(preun): initscripts, chkconfig
Requires(postun): initscripts
Group: Development/Tools

%description server
This package provides an easy-to-use standalone server setup for monotone.


%prep
%setup -q

%build
%configure --with-bundled-lua=%{bundled_lua} \
	   --with-bundled-sqlite=%{bundled_sqlite}
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check || { cat tester_dir/*.log; false; }

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_infodir}/dir
rm -f %{buildroot}%{_datadir}/doc/monotone/monotone.html

%find_lang %{name}

compldir=%{buildroot}%{_sysconfdir}/bash_completion.d
mkdir -p ${compldir}
%{__install} -c -m 0444 contrib/monotone.bash_completion ${compldir}

lispdir=%{buildroot}%{_datadir}/emacs/site-lisp
mkdir -p ${lispdir}
%{__install} -c -m 0444 contrib/monotone*.el ${lispdir}
emacs -batch -f batch-byte-compile ${lispdir}

mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_localstatedir}/lib
ln -snf ../bin/mtn %{buildroot}%{_sbindir}/monotone-server
%{__install} -D -m 0555 %{SOURCE1} \
	     %{buildroot}%{_sysconfdir}/rc.d/init.d/monotone
%{__install} -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/monotone
%{__install} -d -m 0755 %{buildroot}%{_sysconfdir}/monotone
%{__install} -d -m 0750 %{buildroot}%{_sysconfdir}/monotone/private-keys
%{__install} -d -m 0770 %{buildroot}%{_localstatedir}/lib/monotone
%{__install} -d -m 0755 %{buildroot}%{_localstatedir}/run/monotone

# These do not actually wind up in the package, due to %%ghost.
%{__install} -c -m 0440 /dev/null \
	     %{buildroot}%{_sysconfdir}/monotone/passphrase.lua
%{__install} -c -m 0640 /dev/null \
	     %{buildroot}%{_sysconfdir}/monotone/read-permissions
%{__install} -c -m 0640 /dev/null \
	     %{buildroot}%{_sysconfdir}/monotone/write-permissions
%{__install} -c -m 0644 /dev/null \
	     %{buildroot}%{_sysconfdir}/monotone/monotonerc
touch %{buildroot}%{_localstatedir}/lib/monotone/server.mtn

cp %{SOURCE3} .

%clean
rm -f README.monotone-server
rm -rf %{buildroot}

%post
if [ $1 -eq 1 ]
then
	/sbin/install-info %{_infodir}/monotone.info %{_infodir}/dir > /dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ]
then
	/sbin/install-info --delete %{_infodir}/monotone.info %{_infodir}/dir > /dev/null 2>&1 || :
fi

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog INSTALL NEWS README README.changesets UPGRADE
%doc monotone.html

%{_bindir}/mtn
%{_bindir}/mtnopt
%{_infodir}/monotone.info*
%{_datadir}/emacs/site-lisp/monotone*.el*
%{_sysconfdir}/bash_completion.d

%files server
%defattr(-,root,root,-)
%doc README.monotone-server
%{_sbindir}/monotone-server
%{_sysconfdir}/rc.d/init.d/monotone
%dir %attr(0755,monotone,monotone) %{_localstatedir}/run/monotone
%config %{_sysconfdir}/sysconfig/monotone
%dir %attr(0755,root,monotone) %{_sysconfdir}/monotone
%dir %attr(0750,root,monotone) %{_sysconfdir}/monotone/private-keys
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/monotonerc
%attr(0440,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/passphrase.lua
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/read-permissions
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/write-permissions
%dir %attr(0770,monotone,monotone) %{_localstatedir}/lib/monotone
%attr(0660,monotone,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_localstatedir}/lib/monotone/server.mtn

%pre server
# Add "monotone" user per http://fedoraproject.org/wiki/Packaging/UsersAndGroups
getent group monotone > /dev/null || groupadd -r monotone
getent passwd monotone > /dev/null ||
useradd -r -g monotone -r -d %{_localstatedir}/lib/monotone -s /sbin/nologin \
	-c "Monotone Netsync Server" monotone
exit 0

%post server
# Register the monotone service
/sbin/chkconfig --add monotone

%preun server
if [ $1 = 0 ]; then
	/sbin/service monotone stop > /dev/null 2>&1
	/sbin/chkconfig --del monotone
fi

%postun
if [ $1 -gt 1 ]; then
	# Restart the running server: updates its db format when needed.
	/sbin/service monotone condrestart > /dev/null 2>&1 || :
fi


%changelog
* Fri Sep 12 2008 Thomas Moschny <thomas.moschny@gmx.de> - 0.41-1
- Updated for 0.41 release.
- Added mtnopt helper.

* Mon Aug 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.40-2
- fix license tag

* Mon Apr 14 2008 Roland McGrath <roland@redhat.com> - 0.40-1
- Updated for 0.40 release.
- Tweaked trivia for packaging guidelines nits.

* Mon Feb 25 2008 Roland McGrath <roland@redhat.com> - 0.39-1
- Updated for 0.39 release.

* Sat Dec 22 2007 Roland McGrath <roland@redhat.com> - 0.38-2
- Fix monotone-server user creation. (#426607)
- Moved monotone-server database to /var/lib. (#426608)
- Use monotone@ in server key name. (#426609)

* Fri Dec 21 2007 Roland McGrath <roland@redhat.com> - 0.38-1
- Updated for 0.38 release.

* Sat Oct 27 2007 Roland McGrath <roland@redhat.com> - 0.37-3
- Updated for 0.37 release.
- Prevent destroying old passphrase file with 'service monotone genkey'.
- Put LSB standard comments in monotone.init for monotone-server subpackage.

* Tue Aug 28 2007 Roland McGrath <roland@redhat.com> - 0.36-2
- Clean up %%pre script per packaging guidelines.
- Disable ppc and ppc64 builds temporarily since make check fails. (#259161)

* Fri Aug  3 2007 Roland McGrath <roland@redhat.com> - 0.36-1
- Updated for 0.36 release.

* Fri Jul 06 2007 Florian La Roche <laroche@redhat.com> - 0.35-4
- add more requires

* Wed May 16 2007 Roland McGrath <roland@redhat.com> - 0.35-3
- Fix locale dependency in monotone-server init script. (#213893)

* Wed May  9 2007 Roland McGrath <roland@redhat.com> - 0.35-2
- Updated for 0.35 release.
- Avoid unnecessary "db migrate" in monotone-server init script. (#213893)

* Wed Apr  4 2007 Roland McGrath <roland@redhat.com> - 0.34-1
- Updated for 0.34 release.

* Thu Mar  1 2007 Roland McGrath <roland@redhat.com> - 0.33-1
- Updated for 0.33 release.
- Install monotone.bash_completion file.

* Wed Feb 28 2007 Roland McGrath <roland@redhat.com> - 0.32-1
- Updated for 0.32 release.

* Thu Dec 21 2006 Kevin Fenzi <kevin@tummy.com> - 0.31-2
- Bump and rebuild to fix upgrade path

* Sat Nov 11 2006 Roland McGrath <roland@redhat.com> - 0.31-1
- Updated for 0.31 release.

* Tue Oct 10 2006 Roland McGrath <roland@redhat.com> - 0.30-1
- Updated for 0.30 release.
- Fix service script to work around buggy init.d/functions. (#198761)

* Thu Aug  3 2006 Roland McGrath <roland@redhat.com> - 0.28-2
- Updated for 0.28 release. (#198652)
- Move server PID file into /var/run/monotone subdirectory. (#198761)

* Tue Jul 11 2006 Roland McGrath <roland@redhat.com> - 0.27-1
- Updated for 0.27 release.

* Mon May  8 2006 Roland McGrath <roland@redhat.com> - 0.26-2
- Fix service script genkey subcommand.

* Mon Apr 10 2006 Roland McGrath <roland@redhat.com> - 0.26-1
- Updated for 0.26 release.
  - Major changes; see UPGRADE doc file for details.

* Fri Jan  6 2006 Roland McGrath <roland@redhat.com> - 0.25-2
- Restore testsuite fix for nonroot owner of / in build chroot.

* Thu Jan  5 2006 Roland McGrath <roland@redhat.com> - 0.25-1
- Updated for 0.25 release.

* Sun Dec 11 2005 Roland McGrath <roland@redhat.com> - 0.24-1
- Updated for 0.24 release.

* Mon Oct  3 2005 Roland McGrath <roland@redhat.com> - 0.23-1
- Updated for 0.23 release.

* Mon Aug 22 2005 Roland McGrath <roland@redhat.com> - 0.22-4
- Updated for 0.22 release.
- Added monotone-server package.

* Sun Aug  7 2005 Roland McGrath <roland@redhat.com> - 0.21-3
- Work around non-root build user owning / in mock chroot builds.

* Wed Jul 27 2005 Roland McGrath <roland@redhat.com> - 0.21-2
- Include monotone-nav.el too.
- Add BuildRequires on cvs so the test suite can run.

* Mon Jul 18 2005 Roland McGrath <roland@redhat.com> - 0.21-1
- Updated for 0.21 release.
- Install Emacs support.

* Thu Jul  7 2005 Roland McGrath <roland@redhat.com> - 0.20-0.1
- Updated for 0.20 release.
- Added %%check section.
- Cannot use FC4 native sqlite3, need newer bundled one.

* Mon Apr 18 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.4
- Modified summary so that it doesn't contain the name

* Thu Apr 14 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.3
- Modified install-info commands to prevent errors in case of --excludedocs

* Wed Apr 13 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.2
- Added post and postun scripts to take care of .info file
- Added parallel make flags

* Wed Apr 13 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.1
- First version.
